@@ -3,7 +3,6 @@ from typing import Optional, Literal, List
 
 import torch
 from torch import nn
-from torch import nn
 try:
     from typing_extensions import Final
 except:
@@ -112,14 +111,16 @@ class FeedForward(nn.Module):
 
         self.ff_0 = core(dim, expand_dim)
         self.act_fnc = get_act_fnc(act_fnc_name)()
-        self.dropout = nn.Dropout(ff_dropout)
+        self.dropout_0 = nn.Dropout(ff_dropout)
         self.ff_1 = core(expand_dim, out_dim)
+        self.dropout_1 = nn.Dropout(ff_dropout)
 
     def forward(self, x: torch.Tensor) -> torch.Tensor:
         x = self.ff_0(x)
         x = self.act_fnc(x)
-        x = self.dropout(x)
+        x = self.dropout_0(x)
         x = self.ff_1(x)
+        x = self.dropout_1(x)
 
         return x
 
@@ -154,6 +155,7 @@ class PatchEmbeddingXd(XXXConvXdBase):
         patch_size: int,
         dimension: int = 2,
         to_flat: bool = True,
+        use_bias: bool = False,
     ) -> None:
         super().__init__(in_channel=image_channel, out_channel=embedding_dim, dimension=dimension)
 
@@ -161,7 +163,8 @@ class PatchEmbeddingXd(XXXConvXdBase):
             self.in_channel,
             self.out_channel,
             kernel_size=patch_size,
-            stride=patch_size
+            stride=patch_size,
+            bias=use_bias
         )
         self.norm = nn.LayerNorm(self.out_channel) if to_flat else get_norm_layer(f"BatchNorm{self.dimension}d")(self.out_channel)
 
@@ -182,4 +185,18 @@ class PatchEmbeddingXd(XXXConvXdBase):
 
     @torch.jit.ignore
     def no_weight_decay(self) -> List[str]:
-        return ["LayerNorm.weight"] if self.to_flat else [f"BatchNorm{self.dimension}d.weight"]
\ No newline at end of file
+        return ["LayerNorm.weight"] if self.to_flat else [f"BatchNorm{self.dimension}d.weight"]
+
+
+class ChannelFirstLayerNorm(nn.Module):
+    def __init__(self, *arg, **kwargs) -> None:
+        super().__init__()
+
+        self.norm = nn.LayerNorm(*arg, **kwargs)
+
+    def forward(self, x: torch.Tensor) -> torch.Tensor:
+        x = x.permute(0, 2, 3, 1)
+        x = self.norm(x)
+        x = x.permute(0, 3, 1, 2)
+
+        return x
\ No newline at end of file
